@@ -486,6 +486,23 @@ class TranslateJson(object):
             self.all_reg_tex_data += lm.tex_create_body_line([i['name'], i['addr'], \
                     i['reset'], i['des']], self.gitbookpath)
 
+    def get_gitlog(self):
+        gitlog = ''
+        gitlog += '\n最近5次修改:\n\n'
+        gitlog += '|日期|作者|描述|commit_id|\n'
+        gitlog += '|:---|:---|:---|:---|\n'
+        json_dir = os.path.dirname(self.js_file)
+        now_dir = os.getcwd()
+        cmd = 'git log --pretty=format:"| %ad | %cn | %s | %h |" --date=short'
+        os.chdir(json_dir)
+        fd = os.popen(cmd)
+        for i in range(5):
+            line = fd.readline()
+            gitlog += line
+        os.chdir(now_dir)
+        return gitlog
+
+
     def main(self):
         file_msg = os.path.basename(self.js_file).split(".json")[0]
         pp = preprocess.PreProcess()
@@ -554,10 +571,15 @@ class TranslateJson(object):
                             self.create_md3(self.js_dpath[i], lm)
                     self.relist(self.all_reg_list)
                     self.create_all_reg_data(lm)
+                    gitlog = ''
+                    try:
+                        gitlog = self.get_gitlog()
+                    except:
+                        pass
                     with open(os.path.join(self.gitbookpath, 'all_register.md'), 'w') as fc:
-                        fc.write("## 寄存器列表\n\n" + self.all_reg_data)
+                        fc.write("## 寄存器列表\n\n" + self.all_reg_data + gitlog)
                     with open(os.path.join(self.gitbookpath, 'all_register_tex.md'), 'w') as fc:
-                        fc.write("## 寄存器列表\n\n" + self.all_reg_tex_data)
+                        fc.write("## 寄存器列表\n\n" + self.all_reg_tex_data + gitlog)
                     with open(os.path.join(self.gitbookpath, 'detail.md'), 'w') as fc:
                         fc.write(self.reg_data)
                     with open(os.path.join(self.gitbookpath, 'detail.rst'), 'w') as fc:
